@@ -312,32 +312,36 @@ class FlowDetails(tabs.Tabs):
     ) -> tuple[str, list[urwid.Text]]:
         if message.raw_content is None:
             return "", [urwid.Text([("error", "[content missing]")])]
-        elif message.raw_content == b"":
+
+        if message.raw_content == b"":
             if isinstance(message, http.Request):
-                return "", [urwid.Text("No request content")]
+                query = getattr(message, "query", "")
+                if not query:
+                    # No body and no query params
+                    return "", [urwid.Text("No request content")]
+                # else: there are query params -> fall through to render them
             else:
                 return "", [urwid.Text("No content")]
-        else:
-            full = self.master.commands.execute(
-                "view.settings.getval @focus fullcontents false"
-            )
-            if full == "true":
-                limit = sys.maxsize
-            else:
-                limit = ctx.options.content_view_lines_cutoff
 
-            flow_modify_cache_invalidation = hash(
-                (
-                    message.raw_content,
-                    message.headers.fields,
-                    getattr(message, "path", None),
-                )
-            )
-            # we need to pass the message off-band because it's not hashable
-            self._get_content_view_message = message
-            return self._get_content_view(
-                viewmode, limit, flow_modify_cache_invalidation
+        full = self.master.commands.execute(
+            "view.settings.getval @focus fullcontents false"
+        )
+
+        if full == "true":
+            limit = sys.maxsize
+        else:
+            limit = ctx.options.content_view_lines_cutoff
+
+        flow_modify_cache_invalidation = hash(
+            (
+                message.raw_content,
+                message.headers.fields,
+                getattr(message, "path", None),
             )
+        )
+        # we need to pass the message off-band because it's not hashable
+        self._get_content_view_message = message
+        return self._get_content_view(viewmode, limit, flow_modify_cache_invalidation)
 
     @lru_cache(maxsize=200)
     def _get_content_view(
